## ni-cartesian-axis

> Add axes to a graph.

```html
<ni-cartesian-graph>
  <ni-cartesian-axis show grid-lines show-label label="Axis 1" axis-position='bottom'>
  </ni-cartesian-axis>
  <ni-cartesian-axis show grid-lines show-label label="Axis 2" axis-position='top'>
  </ni-cartesian-axis>
  <ni-cartesian-axis show grid-lines show-label label="Axis 3" axis-position='left'>
  </ni-cartesian-axis>
</ni-cartesian-graph>
```
Multiple vertical and horizontal axes can be added to a graph and configured.

Axes can be placed to the right, left and on top or bottom of a graph, can use a
logarithmic scale if desired and can show time. A relative time format is supported
along with the absolute time format.

The minimum and maximum value of an axis can be specified. Autoscaling according
to the data ranges dispayed is also possible.


### ni-cartesian-axis properties

**axis-ref** - an axis id used to bind plots to the axes. Default: ''

**show** (boolean) - if true the axis will be visible. Default: false

**label** (string) - the name of the axis. Default: '' 

**axis-position** (string) - the position of the axis. Default: 'left'
 Accepted values: 'top', 'bottom', 'left' and 'right'


**show-label** (boolean) - if true the axis label will be visible.
               Default: false 

**minimum** (number) - the minimum axis value. Default: 0

**maximum** (number) - the maximum axis value. Default: 1

**auto-scale** (string) - if 'exact' or 'loose' the axis will adapt to the data
               ranges of the plots assigned to that axis. if 'none', the axis will adapt to the
               minimum and maximum options. For 'growexact' and 'growloose' the axis will adapt only when
               the new data value is bigger than the old one. Default: 'auto'

**log-scale** (boolean) - if true the axis will be a log axis. Default: false

**format** (string) - the format of the tick labels. Default: ''
Possible values: 'LVSI, 'LVTime', 'LVRelativeTime', 'LVRelativeSeconds'.
Examples:

|format|value(s)|formatted value(s)|
|------|----:|--------------:|
|_not specified_|0.1234567|0.1234567|
|LVSI|0.1234567|123.4567m|
|LVSI:0|0.1234567|123m|
|LVSI:0.###|0.1234567|123.457m|
|LVSI:G3|0.1234567|123m|
|LVSI:G3|1.234567|1.23|
|LVSI:N3|0.1234567|123.457m|
|LVTime|0|12:00:00 AM 1/1/0001|
|LVTime|300|12:05:00 AM 1/1/0001|
|LVRelativeTime|0, 300, 600|00:00:00, 00:05:00, 00:10:00|
|LVRelativeTime|300, 600, 900|00:00:00, 00:05:00, 00:10:00|
|LVRelativeSeconds:300|300|300.0|
|LVRelativeSeconds:0.###|0.12345678|0.123|
|LVRelativeSeconds:G3|0.12345678|0.123|
|LVRelativeSeconds:G3|1.2345678|1.23|
|LVRelativeSeconds:N3|1234.5678|1234.567|

The actual starting time corresponding to the 0 value for the 'LVTime' format
may vary depending on the time zone.

The first value of each axis using the 'LVRelativeTime' format is considered
the starting point for that axis and it will always be formatted as 00:00:00.

The actual number of decimals may be larger than specified for the endpoints.
When the range of an axis using the 'LVRelativeTime' format is smaller than 1
minute then the milliseconds will be displayed as well.

Other items which are displaying values, like the cursors or cursor legend,
will use this format as well.


* This value represents the total milliseconds to offset the formatted display of
* absolute time on an axis.
* The default will offset a date synonymous with 'new Date(0)' to the date:
* '12:00:00 AM 01/01/0001'


**show-tick-labels** (string) - which of the tick labels are visible.
               Possible values: 'none', 'endpoints', 'major' and 'all'. Default: 'all'.
               For 'endpoints' only the minimum and the maximum values will be visible
               at the edges of the axis. To make some intermediary values visible use
               'major', and 'all' to show all of them.

**ticks** (string) - override x-axis ticks. String must be valid JSON format.
               Example values: undefined, '1', '[1, 2, ...]', or '[[0, "tickLabel0"], [1, "tickLabel1"], ...]'
               Default: undefined

**grid-lines** (boolean) - if true the grid lines for the axis will
               be visible. Default: false

**show-ticks** (boolean) - if true the tick lines for the axis will
               be visible. A tick line is a short line which connects the tick label with
               the axis. Default: false

**show-minor-ticks** (boolean) - if true the minor tick lines for the axis
               will be visible. Minor tick lines are short lines (half of the tick line
               length) which subdivide the interval between tick lines in five intervals.
               Default: false

**tick-size** (string) - sets a fixed tick interval size for the axis
               Value can be a fixed number or an array.
               Note that for time series, the format is an array like [value, unit]
               where unit is one of "second", "minute", "hour", "day", "month" and "year".
               Default: undefined

**min-tick-size** (string) - sets the minimum tick interval size for the axis
               Value can be a fixed number or an array.
               Note that for time series, the format is an array like [value, unit]
               where unit is one of "second", "minute", "hour", "day", "month" and "year".
               Default: undefined

**inverted** (boolean) - if true the axis will display in reverse order 
               (max at bottom/left, min at top/right).
               Default: false

**label-width** (number) - sets the axis width as if the labels were
               this fixed width. For x axes this will ensure a padding size equal to half
               this value on the left and right sides of the graph to ensure space for the
               first and last label but will not affect y padding.
               Default: undefined

**pan** (string) - what type of panning is allowed for the axis.
               Possible values: 'none', 'axis', 'plot', 'all'. Default: 'all'.
               For 'axis' panning can be done only when the mouse/touch is over the axis,
               while for 'plot', the panning is done only if the entire plot is panned. 

**reserve-space** (boolean) - if true the axis will reserve label-width
               space even if the axis is not shown.
               Default: false

**zoom** (string) - what type of panning is allowed for the axis.
               Possible values: 'none', 'axis', 'plot', 'all'. Default: 'all'.
               For 'axis' zooming can be done only when the mouse/touch is over the axis,
               while for 'plot', the zooming is done only if the entire plot is zommed. 
