## Webcharts API methods
The following methods are available for ni-cartesian-graph, ni-chart and
ni-intensity-graph.

**setData** is the prefered method to write data to a graph. The other
option, writing to the *value* property of the element is only recommended
for rarely changed small datasets, since it consumes more memory and CPU
due to the serialization/deserialization needed.

```js
// graph needs to be ready before calling any methods on it
var graph = document.querySelector('#myGraph');
graph.setData([1, 2, 3, 4, 5]);
```

**onRecenterPlot** is used to perform a reset for webcharts. This includes
resetting the offset of the axis and redrawing of the plot.

```js
// graph needs to be ready before calling any methods on it
var graph = document.querySelector('#myGraph');
graph.onRecenterPlot();
```

**updateCompleted** Promise is resolved when the graph has completed updating.
The graph element updates asynchronously in response to its and its nested elements' property changes.
Property changes are batched. If more properties change after an update is requested but before the update begins,
all of the changes are captured in the same update. This results in significant performance improvements in the rich
interaction scenario.

```js
var graph = document.querySelector('#myGraph');
graph.disablePan = true;
graph.disabled = true;
// The above two changes are batched
await graph.updateCompleted;
```


## Webcharts properties

**graph-ref** - a graph id used to bind legends to the graph

**plot-area-margin** - TODO - document this

**disable-pan** - set true to disable the mouse/touch drag interaction
to move the plot. Default: true.

**disable-zoom** - set true to disable the mouse wheel or touch pinch interaction
to zoom in or out the plot. Default: true.

**disable-recenter** - set true to disable the double click/tap interaction
to move and zoom back the plot. Default: true.

**pan-mode** - a string specifies the pan mode for mouse interaction. Accepted values:
'manual': no pan hint or direction snapping;
'smart': The graph shows pan hint bar and the pan movement will snap
to one direction when the drag direction is close to it;
'smartLock'. The graph shows pan hint bar and the pan movement will always
snap to a direction that the drag direction started with.
Default: 'smart'.

**touch-pan-mode** a string specifies the pan mode of touch pan.
The accepted values is the sams as **mode** option. Default: 'manual'

**propagate-supported-gesture** set true to allow the propagation of origin touch events
(e.g. 'touchstart') that is already handled for pan or pinch. Default: false.

## Webcharts events

**ni-graph-created** event is fired on the graph after the flot chart has been created the first time.

**ni-graph-updated** event is fired on the graph when Webcharts has been updated.

**plot-hover** event is fired when the mouse hovers over the graph and enable-hover is set to true. The event data will include that plot element, position and hoverData. hoverData will be null if the mouse is not near a plot. event.preventDefault() can be called in event handlers to disable hover tooltips.