## ni-cartesian-graph

> A custom element that allows to graph one or multiple data sets.

An ni-cartesian-graph is a declarative way, that uses custom elements, to add a graph
to a web page. Specify your data sets using the value attribute and customize how
the data is renderended using nested custom elements such as *ni-cartesian-axis*,
*ni-cartesian-plot*, *ni-cartesian-plot-renderer* or *ni-cursor*.

Example showing how you can render a graph of prime number versus fibonacci numbers.
```html
<ni-cartesian-graph value="[[2, 3, 5, 7, 11, 13, 17, 19],
                          [0, 1, 1, 2, 3, 5, 8, 13]]">
  <ni-cartesian-axis show label="Index" axis-position="bottom"></ni-cartesian-axis>
  <ni-cartesian-axis show label="Value" axis-position="left"></ni-cartesian-axis>
  <ni-cartesian-plot show label="Prime Numbers">
    <ni-cartesian-plot-renderer line-width="2" line-stroke="red">
    </ni-cartesian-plot-renderer>
  </ni-cartesian-plot>
  <ni-cartesian-plot show label="Fibonacci Numbers">
    <ni-cartesian-plot-renderer line-width="2" line-stroke="blue">
    </ni-cartesian-plot-renderer>
  </ni-cartesian-plot>
</ni-cartesian-graph>
```


## Data types supported by the ni-cartesian-graph

Data can be passed to a graph either through writing to the element value
property or using API access (the setData() method on the element).

Here is a list of supported data types:


* **A 1D array of numerics**
```js
[a1, a2, a3]
```
Will be drawn as a single plot. It's an efficient and fast way to
pass data to the graph.

A typed array view is also allowed.


* **A 2D array of numerics**
```js
[[a1, a2, a3], [b1, b2, b3]]
```
Will be drawn as multiple plots. It's an efficient and fast way to
pass data to the graph.

An array of typed array views is also allowed.


* **An analogWaveform**
```js
var data = new NIAnalogWaveform({
    t0: new NITimestamp(),
    dt: 0.001, // 1 ms
    Y: [a1, a2, a3]
});
```
Will be drawn as a single plot. It's an
efficient and fast way to pass data to the graph


* **An array of analogWaveforms**
```js
var aw0 = new NIAnalogWaveform({
    t0: new NITimestamp(),
    dt: 0.001, // 1 ms
    Y: [a1, a2, a3]
});
var aw1 = new NIAnalogWaveform({
    t0: new NITimestamp(),
    dt: 0.001, // 1 ms
    Y: [b1, b2, b3]
});
var data = [aw0, aw1];
```
Will be drawn as multiple plots. It's an efficient and fast way to
pass data to the graph.


* **An object (cluster) of arrays**
```js
var data = {a: [a1, a2, a3], b: [b1, b2, b3]};
```
 Will be drawn as a single XY plot,
the first array will hold the X coordinates and the second the Y
coordinates. This format is only recomended when you want to display
XY data, it's not particulary efficient or fast.


* **An array of objects (clusters) of arrays**
```js
var data = [
    {a: [a1, a2, a3], b: [b1, b2, b3]},
    {c: [c1, c2, c3], d: [d1, d2, d3]}
];
```
Will be drawn as multiple XY plots, the first array in the object
(cluster) will hold the X coordinates and the second the Y coordinates.
This format is only recomended when you want to display XY data,
it's not particulary efficient or fast.


* **An array of objects (clusters)**
```js
var data = [
    {x: a1, y: b1},
    {x: a2, y: b2},
    {x: a3, y: b3},
];
```
Will be drawn as a single XY plot, the first element in the cluster
will hold the X coordinates and the second the Y coordinates. This
format is only recomended when you want to display XY data, it's not
particulary efficient or fast.


* **An array of array of objects (clusters)**
```js
var data = [
    [{x: a1, y: b1}, {x: a2, y: b2}, {x: a3, y: b3}],
    [{x: c1, y: d1}, {x: c2, y: d2}, {x: c3, y: d3}]
];
```
Will be drawn as multiple XY plots, the first element in the cluster
will hold the X coordinates and the second the Y coordinates. This
format is only recomended when you want to display XY data, it's not
particulary efficient or fast.


* **An 1D array of Complex Numbers**
```js
var a1 = new NIComplex(1, 2);
var a2 = new NIComplex(2, 3);
var a3 = new NIComplex(3, 4);
var data = [a1, a2, a3]; // array of complex numbers
var data2 = ['1+2i', '2+3i', '3+4i']; // also accepted as input
```
Will be drawn as a single plot.


* **A 2D array of Complex Numbers**
```js
var a1 = new NIComplex(1, 2);
var a2 = new NIComplex(2, 3);
var b1 = new NIComplex(3, 4);
var b2 = new NIComplex(4, 5);
var data = [[a1, a2], [b1, b2]]; // arrays of complex numbers
var data2 = [['1+2i', '2+3i'], ['3+4i', '4+5i']]; // also accepted as input
```
Will be drawn as multiple plots.
