# Styling the Webcharts

Webcharts styling through CSS is still WIP and the ability to style them through
CSS is limited.

The anatomy of a webchart is a bit complex though, it is made of multiple drawing
layers, some that can be styled with CSS, some can be partially styled with CSS
and some can't be styled at all yet.

The drawing layers of a webchart are all situated in a div (with the css class
webchart-drawing-layer) that is built at element creation time. The nested
elements of a webchart (ni-cartesian-axis, ni-cartesian-plot ...) don't have
any visible parts, they only hold configuration and their styles are often
read and applied to the drawing layer.

The drawing layer is composed of:

* two overlapping canvas layers, one used for the the plots, axes and grid,
the other one used for drawing UI stuff, like cursors, navigation hints,
tooltips ...
* a text layer (svg) for each axis, where the tick labels and the
axis labels are drawn
* an svg layer for each axis
* a fake grid layer (an ni-grid-div element, with visibility none). Some of the
styles of this are applyed to the grid draw on the canvas layer.

The examples below show how to change the styles of all the webcharts on the
page, if you want to change the look on a webchart by webchart basis you'll use
CSS selectors or inline styles to target a specific one.



## The top level elements

These are custom elements and they are styled entirely using CSS. They respect
the CSS box model. The most useful properties to tweak here are the *color*,
*background-color*, *padding* and *margin*


```css
ni-cartesian-graph,
ni-chart,
ni-intensity-graph,
ni-digital-graph {
    border: 1px solid #C7CCD0;
    padding: 20px;
    color: #2B3033;
    width: 600px;
    height: 400px;
    background-color: green;
}
```


## Touch/Text Highlight

These CSS properties are used to disable text highlight and long-tap highlight:

```css
ni-cartesian-graph,
ni-chart,
ni-intensity-graph,
ni-digital-graph {
    -webkit-tap-highlight-color: rgba(0,0,0,0);
    -webkit-tap-highlight-color: transparent;           - Some Android devices
    -webkit-touch-callout: none;                        - iOS Safari
    -webkit-user-select: none;                          - Safari
    -khtml-user-select: none;                           - Konqueror HTML
    -moz-user-select: none;                             - Firefox
    -ms-user-select: none;                              - Internet Explorer and Edge
    user-select: none;                                  - Chrome and Opera
}
```


## The grid

The grid is drawn on the canvas element. At every redraw styles from
the *ni-grid-div* are used to configure how the grid is drawn

Example of a grid with darkred, 2 pixels wide borders on top and bottom,
with a white background and red reticles:

```css
ni-cartesian-graph ni-grid-div,
ni-chart ni-grid-div,
ni-intensity-graph ni-grid-div,
ni-digital-graph ni-grid-div {
    border-style: solid;
    border-width: 2px 0px 2px 0px;
    border-color: darkred;
    background-color: white;
    color: red;
}
```

CSS properties applied when drawing the grid.


* **border-style** - use solid or none. dashed borders not supported

* **border-width** - top left botton right

* **border-color** - the color of the border

* **background-color** - the background color of the grid

* **color** - the color of the grid reticles

## The axes

The axes are drawn on the canvas element and the axis ticks are drawn on their
own SVG layers . At every redraw, the styles from the corresponding
*ni-cartesian-axis* are used to configure how the axes are drawn.
To apply these styles to the axes, used when creating a snapshot,
the snapshot class must be applied. Otherwise, the default styles are used.

```css
ni-cartesian-axis,
.snapshot text.axisLabels {
    font-family: "Open Sans", verdana, arial, sans-serif;
    font-size: 12px;
    font-style: normal;
    color: #C7CCD0;
}
```

The fonts styles and fill property are used for the axis ticks and the color is used
for drawing the axes and major and minor ticks.

The tick labels color is inherited from the main element style.
Since SVG is used to draw labels, the color should be specified as fill property.


## The axis labels

The axis labels are drawn as text on a SVG layer with a CSS class
*"axisLabels"*

Example of 16px, purple axis labels

```css
ni-cartesian-graph text.axisLabels,
ni-chart text.axisLabels,
ni-intensity-graph text.axisLabels,
ni-digital-graph text.axisLabels,
.snapshot text.axisLabels {
    font-family: "Open Sans", verdana, arial, sans-serif;
    font-size: 16px;
    fill: purple;
}
```


## The tick labels

The tick labels of the axes are drawn as text on a HTML layer with
*"flot-x-axis"* and *"flot-y-axis"* CSS class respectively for each direction

Example of 16px, purple tick labels for all axes

```css
ni-cartesian-graph .flot-x-axis text,
ni-cartesian-graph .flot-y-axis text,
ni-chart .flot-x-axis text,
ni-chart .flot-y-axis text,
ni-intensity-graph .flot-x-axis text,
ni-intensity-graph .flot-y-axis text,
ni-digital-graph .flot-x-axis text {
    font-family: "Open Sans", verdana, arial, sans-serif;
    font-size: 16px;
    color: purple;
}
```

It is possible to customize the tick labels of each axis by using a selector
specific to each axis: *"flot-x1-axis"*, *"flot-x2-axis"*, etc.


## The cursors

The cursors are drawn on the canvas element. At every redraw, the styles from the corresponding
*ni-cursor* are used to configure how the cursors are drawn.

```css
ni-cursor {
    font-family: "Open Sans", verdana, arial, sans-serif;
    font-size: 12px;
    font-style: normal;
    color: #2B3033;
}
```

The fonts styles and fill property are used for the cursor label and the color is used
for drawing the markings and simbol.


## The thumbs
Thumbs are drawn on a svg element. The styles from .thumb, .thumbLabel, and .thumbIcon
classes are used to configure how the thumbs are drawn. A thumb is an svg <g> element having .thumb class.
Each thumb has 2 children, an icon (svg <use> element with .thumbIcon class) and
a label (svg <text> element with .thumbLabel class).

```css
.thumb {
    stroke: blue;
    fill: blue;
    stroke-width: 2px;
}

.thumbLabel {
    stroke-width: 1px;
    font-size: 16px;
    font-family: "Open Sans", verdana, arial, sans-serif;
    font-style: normal;
}

.thumbIcon {
    fill: lightskyblue;
}
```
